@@ -46,7 +46,9 @@
 #include <termcap.h>	/* ospeed */
 #include <tic.h>
 
-MODULE_ID("$Id: lib_tputs.c,v 1.41 1999/10/22 23:31:24 tom Exp $")
+MODULE_ID("$Id: lib_tputs.c,v 1.39 1999/02/25 10:44:29 tom Exp $")
+
+#define OUTPUT ((SP != 0) ? SP->_ofp : stdout)
 
 char PC;		/* used by termcap library */
 speed_t ospeed;		/* used by termcap library */
@@ -68,7 +70,7 @@ int delay_output(int ms)
 		for (_nc_nulls_sent += nullcount; nullcount > 0; nullcount--)
 			my_outch(PC);
 		if (my_outch == _nc_outch)
-			_nc_flush();
+			(void) fflush(OUTPUT);
 	}
 
 	returnCode(OK);
@@ -80,17 +82,7 @@ int _nc_outch(int ch)
     	_nc_outchars++;
 #endif /* TRACE */
 
-	if (SP != 0
-	 && SP->_cleanup) {
-		char tmp = ch;
-		/*
-		 * POSIX says write() is safe in a signal handler, but the
-		 * buffered I/O is not.
-		 */
-		write(fileno(NC_OUTPUT), &tmp, 1);
-	} else {
-		putc(ch, NC_OUTPUT);
-	}
+	putc(ch, OUTPUT);
 	return OK;
 }
 
