@@ -73,7 +73,7 @@
 
 #include <term.h>
 
-MODULE_ID("$Id: tty_update.c,v 1.117 1999/10/22 23:28:46 tom Exp $")
+MODULE_ID("$Id: tty_update.c,v 1.112 1999/09/04 13:13:45 tom Exp $")
 
 /*
  * This define controls the line-breakout optimization.  Every once in a
@@ -95,10 +95,10 @@ MODULE_ID("$Id: tty_update.c,v 1.117 1999/10/22 23:28:46 tom Exp $")
 
 static inline chtype ClrBlank ( WINDOW *win );
 static int ClrBottom(int total);
+static int InsStr( chtype *line, int count );
 static void ClearScreen( chtype blank );
 static void ClrUpdate( void );
 static void DelChar( int count );
-static void InsStr( chtype *line, int count );
 static void TransformLine( int const lineno );
 
 #ifdef POSITION_DEBUG
@@ -108,40 +108,29 @@ static void TransformLine( int const lineno );
  *
  ****************************************************************************/
 
-static void position_check(int expected_y, int expected_x, char *legend)
+void position_check(int expected_y, int expected_x, char *legend)
 /* check to see if the real cursor position matches the virtual */
 {
-    char  buf[20];
+    static char  buf[9];
     int y, x;
 
-    if (!_nc_tracing || (expected_y < 0 && expected_x < 0))
+    if (_nc_tracing)
 	return;
 
     memset(buf, '\0', sizeof(buf));
-    putp("\033[6n");	/* only works on ANSI-compatibles */
-    _nc_flush();
-    (void) read(0, buf, sizeof(buf)-1);
+    (void) write(1, "\033[6n", 4);	/* only works on ANSI-compatibles */
+    (void) read(0, (void *)buf, 8);
     _tracef("probe returned %s", _nc_visbuf(buf));
 
     /* try to interpret as a position report */
-    if (sscanf(buf, "\033[%d;%dR", &y, &x) != 2) {
+    if (sscanf(buf, "\033[%d;%dR", &y, &x) != 2)
 	_tracef("position probe failed in %s", legend);
-    } else {
-	if (expected_x < 0)
-	    expected_x = x - 1;
-	if (expected_y < 0)
-	    expected_y = y - 1;
-	if (y - 1 != expected_y || x - 1 != expected_x) {
-	    beep();
-	    _tracef("position seen (%d, %d) doesn't match expected one (%d, %d) in %s",
-		    y-1, x-1, expected_y, expected_x, legend);
-	} else {
-	    _tracef("position matches OK in %s", legend);
-	}
-    }
+    else if (y - 1 != expected_y || x - 1 != expected_x)
+	_tracef("position seen (%d, %d) doesn't match expected one (%d, %d) in %s",
+		y-1, x-1, expected_y, expected_x, legend);
+    else
+	_tracef("position matches OK in %s", legend);
 }
-#else
-#define position_check(expected_y, expected_x, legend) /* nothing */
 #endif /* POSITION_DEBUG */
 
 /****************************************************************************
@@ -157,7 +146,9 @@ static inline void GoTo(int const row, int const col)
 	TR(TRACE_MOVE, ("GoTo(%d, %d) from (%d, %d)",
 			row, col, SP->_cursrow, SP->_curscol));
 
+#ifdef POSITION_DEBUG
 	position_check(SP->_cursrow, SP->_curscol, "GoTo");
+#endif /* POSITION_DEBUG */
 
 	/*
 	 * Force restore even if msgr is on when we're in an alternate
@@ -175,7 +166,6 @@ static inline void GoTo(int const row, int const col)
 	mvcur(SP->_cursrow, SP->_curscol, row, col);
 	SP->_cursrow = row;
 	SP->_curscol = col;
-	position_check(SP->_cursrow, SP->_curscol, "GoTo2");
 }
 
 static inline void PutAttrChar(chtype ch)
@@ -187,14 +177,10 @@ static inline void PutAttrChar(chtype ch)
 			  _tracechtype(ch),
 			   SP->_cursrow, SP->_curscol));
 	UpdateAttrs(ch);
-	if (SP->_cleanup) {
-		_nc_outch((int)TextOf(ch));
-	} else {
-		putc((int)TextOf(ch), SP->_ofp); /* macro's fastest... */
+	putc((int)TextOf(ch), SP->_ofp);
 #ifdef TRACE
-		_nc_outchars++;
+	_nc_outchars++;
 #endif /* TRACE */
-	}
 	SP->_curscol++;
 	if (char_padding) {
 		TPUTS_TRACE("char_padding");
@@ -256,7 +242,7 @@ static bool check_pending(void)
 	}
 	if (have_pending) {
 		SP->_fifohold = 5;
-		_nc_flush();
+		fflush(SP->_ofp);
 	}
 	return FALSE;
 }
@@ -288,8 +274,6 @@ static void PutCharLR(chtype const ch)
 	putp(exit_am_mode);
 
 	PutAttrChar(ch);
-	SP->_curscol--;
-	position_check(SP->_cursrow, SP->_curscol, "exit_am_mode");
 
 	TPUTS_TRACE("enter_am_mode");
 	putp(enter_am_mode);
@@ -336,7 +320,6 @@ static void wrap_cursor(void)
     {
 	SP->_curscol--;
     }
-    position_check(SP->_cursrow, SP->_curscol, "wrap_cursor");
 }
 
 static inline void PutChar(chtype const ch)
@@ -350,7 +333,9 @@ static inline void PutChar(chtype const ch)
     if (SP->_curscol >= screen_columns)
 	wrap_cursor();
 
+#ifdef POSITION_DEBUG
     position_check(SP->_cursrow, SP->_curscol, "PutChar");
+#endif /* POSITION_DEBUG */
 }
 
 /*
@@ -781,7 +766,7 @@ struct tms before, after;
 	 */
 	UpdateAttrs(A_NORMAL);
 
-	_nc_flush();
+	fflush(SP->_ofp);
 	curscr->_attrs = newscr->_attrs;
 /*	curscr->_bkgd  = newscr->_bkgd; */
 
@@ -929,14 +914,13 @@ chtype	blank  = newscr->_line[total-1].text[last-1]; /* lower right char */
 
 	if ((tstLine == 0) || (last > (int)lenLine)) {
 		tstLine = typeRealloc(chtype, last, tstLine);
-		if (tstLine != 0) {
-			lenLine = last;
-			for (col = 0; col < last; col++)
-				tstLine[col] = blank;
-		}
 	}
 
 	if (tstLine != 0) {
+		lenLine = last;
+		for (col = 0; col < last; col++)
+			tstLine[col] = blank;
+
 		for (row = total-1; row >= 0; row--) {
 			if (memcmp(tstLine, newscr->_line[row].text, length))
 				break;
@@ -1241,7 +1225,9 @@ static void ClearScreen(chtype blank)
 		TPUTS_TRACE("clear_screen");
 		putp(clear_screen);
 		SP->_cursrow = SP->_curscol = 0;
+#ifdef POSITION_DEBUG
 		position_check(SP->_cursrow, SP->_curscol, "ClearScreen");
+#endif /* POSITION_DEBUG */
 	} else if (clr_eos) {
 		SP->_cursrow = SP->_curscol = -1;
 		GoTo(0,0);
@@ -1279,7 +1265,7 @@ static void ClearScreen(chtype blank)
 **
 */
 
-static void InsStr(chtype *line, int count)
+static int InsStr(chtype *line, int count)
 {
 	T(("InsStr(%p,%d) called", line, count));
 
@@ -1294,6 +1280,7 @@ static void InsStr(chtype *line, int count)
 			line++;
 			count--;
 		}
+		return(OK);
 	} else if (enter_insert_mode  &&  exit_insert_mode) {
 		TPUTS_TRACE("enter_insert_mode");
 		putp(enter_insert_mode);
@@ -1309,6 +1296,7 @@ static void InsStr(chtype *line, int count)
 		}
 		TPUTS_TRACE("exit_insert_mode");
 		putp(exit_insert_mode);
+		return(OK);
 	} else {
 		while (count) {
 			TPUTS_TRACE("insert_character");
@@ -1322,8 +1310,8 @@ static void InsStr(chtype *line, int count)
 			line++;
 			count--;
 		}
+		return(OK);
 	}
-	position_check(SP->_cursrow, SP->_curscol, "InsStr");
 }
 
 /*
@@ -1357,8 +1345,14 @@ static void DelChar(int count)
 
 void _nc_outstr(const char *str)
 {
-    (void) putp(str);
-    _nc_flush();
+    FILE *ofp = SP ? SP->_ofp : stdout;
+
+    (void) fputs(str, ofp);
+    (void) fflush(ofp);
+
+#ifdef TRACE
+    _nc_outchars += strlen(str);
+#endif /* TRACE */
 }
 
 /*
